pro bigplot_v5b

; dhc - 19sep10 - v5 but with a squarer aspect ratio

; modified from v1b on 10mar08 to handle four column (data only) files
; v4 includes Emma's code to read in both grating arms from a single file
;
; reads in two four-column ascii files: 

; col 1 = wavelength
; col 2 = bin half-width 
; col 3 = data
; col 4 = uncertainty
;
; builds on fitplot*_v5
;


; SETTING THE OBSERVATION-SPECIFIC EXPOSURE TIME

exptime=139180.
print, 'EXPOSURE TIME HARDWIRED TO 139180s FOR HD93129'


; SETTING GRATING
grating = ''
read,grating,prompt='Enter grating: (m/h) '
case grating of
'm':igrating=1
'h':igrating=2
else: begin
	print,'No grating chosen. Assuming MEG.'
	igrating=1
      end
endcase


;
; SETTING THE TERMINAL VELOCITY ASSUMED FOR THE WIND
; AND THE LAB REST WAVELENGTH
; MATTERS ONLY FOR DRAWING VERTICAL LINES ON PLOT

c=3.e5
vinf=3200.

; LIST OF LAB WAVELENGTHS OF STRONG LINES

lines=[5.0387,5.0631,5.1015,6.1821,6.6479,6.685,6.7403,7.8503,8.421,9.1688,9.2308,9.3143,12.1339,13.447,13.518,13.553,15.014]
num_lines=n_elements(lines)

print, 'number of lines =',num_lines
print, 'wavelengths =',lines

; USER MUST ALSO SET THE NUMBER OF LINES IN THIS LIST


; SWITCH FOR DRAWING ONE or THREE VERTICAL LINES

ivert=1

; GET NAME OF FILE TO BE READ

filename = '*.dat'
file = dialog_pickfile(/read, filter = filename)


; READ IN THE FILES AND POPULATE ARRAYS

if (igrating eq 1) then begin
	getdatafile_mm,file,wave1,width1,data1,error1
	getdatafile_mp,file,wave2,width2,data2,error2
endif else begin
	getdatafile_hm,file,wave1,width1,data1,error1
	getdatafile_hp,file,wave2,width2,data2,error2
endelse


; ADD CONTENTS OF TWO INPUT FILES

; CHECK WAVELENGTH SCALES

num1=n_elements(wave1)
num2=n_elements(wave2)
print, 'number of elements: ', num1, num2

wave_check = where((wave1-wave2),count)
print, 'NUMBER OF ELEMENTS FOR WHICH WAVELENGTH ARRAYS DISAGREE = ',count

; ADD DATA, ETC. FROM TWO INPUT FILES

; WAVELENGTH IS JUST ADOPTED FROM THE FIRST FILE

wave=wave1


; DATA ARE IN COUNTS/S/ANG
; WE WANT TOTAL COUNTS PER BIN, the bin full width is .005 A for MEG

if (igrating eq 1) then begin
bin_width=0.005
print, 'MEG'
endif else begin
bin_width=0.0025
print, 'HEG'
endelse


total_counts = (data1+data2)*exptime*bin_width
error_poisson = sqrt(total_counts)

; NOW CONVERT BACK TO ORIGINAL DATA UNITS, AND ADD TOGETHER TWO SPECTRA

data=data1+data2
error=error_poisson/exptime/bin_width


; MAKE A RUDIMENTARY PLOT


; SETTING SOME PARAMETERS

xrdata=[min(wave),max(wave)]
yrdata=[0.,(max(data)+max(error))]


; OVERRIDE X-RANGE, Y-RANGE AUTO-CHOOSING

;xrdata=[4.8,10.2]
xrdata=[5.,25.2]
yrdata=[0.0,0.03]
; optimized for MEG (see below for binspacing too)
yrdata=[0.0,0.022]
; for HEG


xtit = 'Wavelength ('+STRING("305B)+')'
ytit = 'Count Rate (counts s!u-1!n '+string("305B)+'!u-1!n)'

; AND PLOTTING (TO IDL SCREEN WINDOW)

for i=1,2 do begin
print, i


if (i EQ 1) then begin
window

; setting up colors for .ps

blue = fsc_color("blue")
red = fsc_color("red")
green = fsc_color("green")

print, i
endif else begin
psopen,ps,/color

; setting up colors for .ps

blue = fsc_color("blue")
red = fsc_color("red")
green = fsc_color("green")

!p.font=0
device,/times
device,/inches,xsize=35.0,ysize=8.0
print, i
endelse

plot,wave,data,ps=10,thick=3,xr=xrdata,yr=yrdata,xstyle=1,ystyle=1,ytit=ytit,chars=3.5,xtit=xtit,xtickinterval=1

;oploterr,wave,data,error,10
;oplot,wave,model,ps=10,linestyle=1,thick=4,color=red

; PLOTTING VERTICAL LINES AT LINE CENTER AND AT THE TWO EDGES

if ivert EQ 1 then begin


for j=0,num_lines-1 do begin

lam_o=lines(j)

x_center=[lam_o,lam_o]
y_center=[0.,1.]

lam_left=lam_o*(1.-vinf/c)
lam_right=lam_o*(1.+vinf/c)

if ivert EQ 3 then begin

x_left=[lam_left,lam_left]
y_left=y_center

x_right=[lam_right,lam_right]
y_right=y_center

endif

   oplot,x_center,y_center,linestyle=2,thick=1

if ivert EQ 3 then begin

   oplot,x_left,y_left,linestyle=1,thick=1
   oplot,x_right,y_right,linestyle=1,thick=1

endif

endfor

endif


endfor

if (i EQ 1) then begin
print, i
endif else begin
psclose
endelse



end
