pro fitplot_xspec_coadd_v8_15014


; reads in two five-column ascii files: 

; col 1 = wavelength
; col 2 = bin half-width 
; col 3 = data
; col 4 = uncertainty
; col 5 = model

; this version of the code reads in TWO files: assumed to be -1 and +1 MEG orders
; NO! v6 now reads in a single output (from iplot > wdata) file, header, separators and all
;
;
; it asks the user for the exposure time and uses this information to calculate the 
; Poisson errors on the data (ignoring the error column read in)
;
; a screen plot and a postscript file are both produced, with the data + Poisson
; errors as a solid histogram and the model overplotted as a dotted histogram
; 
; the data and models (and errors) are co-added, and plotted in the usual xspec data 
; units: counts/s/A
;
;
; beta Cru: ObsID 2725 --> exposure time=74379 seconds
; zeta Pup: ObsID 640 --> exposure time=67636 seconds
; epsilon Ori: ObsID 3753 --> exposure time=91645.9609 seconds
;
; v.3 (28may07) implements fit redisuals plot window
; v.4 (29may07) plots both to window and to postscript file
; v.5 (8jun07) vertical lines at lam_o, and -/+ vinf
; v.6 (28may08) EEW --> reads in a single, undoctored data file
;
; v.7 (22dec08) DHC --> darker axis lines (box all around plot)
; 

; SETTING THE OBSERVATION-SPECIFIC EXPOSURE TIME

exptime=91645.9609
print, 'EXPOSURE TIME HARDWIRED TO 91646s FOR EPSILON ORI'
;exptime=67636.
;print, 'EXPOSURE TIME HARDWIRED TO 67636s FOR ZETA PUP'

; SETTING GRATING
grating = ''
read,grating,prompt='Enter grating: (m/h) '
case grating of
'm':igrating=1
'h':igrating=2
else: begin
	print,'No grating chosen. Assuming MEG.'
	igrating=1
      end
endcase

; SETTING THE TERMINAL VELOCITY ASSUMED FOR THE WIND
; AND THE LAB REST WAVELENGTH
; MATTERS ONLY FOR DRAWING VERTICAL LINES ON PLOT

c=3.e5
vinf=1600.
;lam_o=6.1822
;lam_o=12.1339
lam_o=15.014
;lam_o=18.9689
delta_plot = .008   ; fraction of speed of light that corresponds to half-width of plot
;delta_plot = .1    ; fraction of speed of light that corresponds to half-width of plot
y_upp_meg = 0.07
y_upp_heg = 0.03

; SWITCH FOR DRAWING THREE VERTICAL LINES

ivert=1

x_center=[lam_o,lam_o]
y_center=[0.,1.]

lam_left=lam_o*(1.-vinf/c)
lam_right=lam_o*(1.+vinf/c)

x_left=[lam_left,lam_left]
y_left=y_center

x_right=[lam_right,lam_right]
y_right=y_center

; GET NAME OF FILE TO BE READ

filename = '*.dat'
file = dialog_pickfile(/read, filter = filename)

; READ IN THE FILES AND POPULATE ARRAYS

if (igrating eq 1) then begin
	getspecfile_mm,file,wave1,width1,data1,error1,model1
	getspecfile_mp,file,wave2,width2,data2,error2,model2
endif else begin
	getspecfile_hm,file,wave1,width1,data1,error1,model1
	getspecfile_hp,file,wave2,width2,data2,error2,model2
endelse

; ADD CONTENTS OF TWO INPUT FILES

; CHECK WAVELENGTH SCALES

num1=n_elements(wave1)
num2=n_elements(wave2)
print, 'number of elements: ', num1, num2

wave_check = where((wave1-wave2),count)
print, 'NUMBER OF ELEMENTS FOR WHICH WAVELENGTH ARRAYS DISAGREE = ',count

; ADD DATA, ETC. FROM TWO INPUT FILES

; WAVELENGTH IS JUST ADOPTED FROM THE FIRST FILE

wave=wave1

; DATA ARE IN COUNTS/S/ANG
; WE WANT TOTAL COUNTS PER BIN, the bin full width is .005 A for MEG

if (igrating eq 1) then begin
bin_width=0.005
print, 'MEG'
endif else begin
bin_width=0.0025
print, 'HEG'
endelse

print, 'CODE ASSUMES MEG or HEG DATA WITH BIN WIDTH =', bin_width

;print, 'What is the effective exposure time?'
;read, exptime
; NOTE: THE EXPOSURE TIME IS SET AT THE TOP OF THE PROGRAM

total_counts = (data1+data2)*exptime*bin_width
error_poisson = sqrt(total_counts)

; NOW CONVERT BACK TO ORIGINAL DATA UNITS, AND ADD TOGETHER TWO SPECTRA

data=data1+data2
error=error_poisson/exptime/bin_width
model=model1+model2

; CALCULATING FIT RESIDUALS

resid=data-model
resid_err=error

; MAKE A RUDIMENTARY PLOT

; SETTING UP THE PARAMETERS OF THE TWO STACKED WINDOWS

yrresid=[min(resid),max(resid)]
horiz=[.12,.95]	;horizontal coords of plots (about default)
verti=[.12,.29,.95]	;vertical coords of plots
	

;THE HORIZ AND VERTI LINES DEFINE THE AREAS COVERED BY THE WINDOWS, THEY
;ESSENTIALLY SET MARKS (TWO IN THE HORIZONTAL DIRECTION AND THREE IN THE 
;VERTICAL DIRECTION) THAT LATER WILL DEFINE THE SIDES, TOP, AND BOTTOM
;OF THE RESPECTIVE PLOTTING BOXES

	!P.MULTI = [0,1,2]


; SETTING SOME PARAMETERS

xrdata=[min(wave),max(wave)]

; OVERRIDE X-RANGE AUTO-CHOOSING FOR THE LINE AT 8.421

xrdata=[(1.-delta_plot)*lam_o,(1.+delta_plot)*lam_o]

if (igrating eq 1) then begin
yrdata=[0.0,y_upp_meg]   ;MEG
endif else begin
yrdata=[0.0,y_upp_heg]   ;HEG
endelse

xtit = 'Wavelength ('+STRING("305B)+')'
ytit = 'Count Rate (counts s!u-1!n '+string("305B)+'!u-1!n)'

; AND PLOTTING (TO IDL SCREEN WINDOW)

for i=1,2 do begin
;print, i

; DATA PLOT

if (i EQ 1) then begin
window

; setting up colors for .ps

blue = cgColor("blue")
red = cgColor("red")
green = cgColor("green")

;print, i
endif else begin
psopen,ps,/color

; setting up colors for .ps

blue = cgColor("blue")
red = cgColor("red")
green = cgColor("green")

!p.font=0
device,/times
;print, i
endelse

psym,'square',/fill,thick=thick

; ps=8 -> custom shape (psym setting)
; ps=10 -> histogram (must change oploterr arg as well as plot ps= arg)

plot,wave,data,ps=8,thick=4,xr=xrdata,yr=yrdata,xstyle=1,ystyle=1,xtickname=[' ',' ',' ',' ',' ',' ',' ',' '],ytit=ytit,chars=1.6, $	
   position=[horiz[0],verti[1],horiz[1],verti[2]],ytickname=[' '],$
   ymargin=[0,2],xthick=2,ythick=2,symsize=1.35

oploterr,wave,data,error,8
oplot,wave,model,ps=10,linestyle=0,thick=8,color=red

; PLOTTING VERTICAL LINES AT LINE CENTER AND AT THE TWO EDGES

if ivert EQ 1 then begin

   oplot,x_center,y_center,linestyle=2,thick=2
   oplot,x_left,y_left,linestyle=1,thick=2
   oplot,x_right,y_right,linestyle=1,thick=2

endif


; RESIDUALS PLOT

psym_circ

plot,wave,resid,ps=8,thick=4,xr=xrdata,xstyle=1,xtit=xtit,chars=1.6, $	
   position=[horiz[0],verti[0],horiz[1],verti[1]],yr=[-.04,.04],yticks=2,ymargin=[0,4],ys=1, $
   xmargin=[2,2],xthick=2,ythick=2

oploterr,wave,resid,resid_err,1

zeroline = [0,0]
oplot,xrdata,zeroline,ps=10,thick=3,linestyle=2

endfor

if (i EQ 1) then begin
;print, i
endif else begin
psclose
endelse

!P.MULTI = 0	;restores the default: 1 plot per page


end
